@@ -36,7 +36,7 @@ import * as lambda from 'aws-cdk-lib/aws-lambda';
 
 new ApiGatewayToLambda(this, 'ApiGatewayToLambdaPattern', {
   lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_16_X,
+    runtime: lambda.Runtime.NODEJS_20_X,
     handler: 'index.handler',
     code: lambda.Code.fromAsset(`lambda`)
   }
@@ -55,7 +55,7 @@ from constructs import Construct
 
 ApiGatewayToLambda(self, 'ApiGatewayToLambdaPattern',
             lambda_function_props=_lambda.FunctionProps(
-                runtime=_lambda.Runtime.PYTHON_3_9,
+                runtime=_lambda.Runtime.Python_3_11,
                 handler='index.handler',
                 code=_lambda.Code.from_asset('lambda')
             )
@@ -76,7 +76,7 @@ import software.amazon.awsconstructs.services.apigatewaylambda.*;
 
 new ApiGatewayToLambda(this, "ApiGatewayToLambdaPattern", new ApiGatewayToLambdaProps.Builder()
         .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_16_X)
+                .runtime(Runtime.NODEJS_20_X)
                 .code(Code.fromAsset("lambda"))
                 .handler("index.handler")
                 .build())
